@@ -1,4 +1,4 @@
-package Pcore::API::Whois v0.3.1;
+package Pcore::API::Whois v0.3.2;
 
 use Pcore -dist, -class;
 use Pcore::API::Whois::Server;
@@ -39,12 +39,12 @@ sub _build_cfg ($self) {
         $cfg->{server}->{$server}->{query} = $db->{server_query}->{$server} // ( $Net::Whois::Raw::Data::query_prefix{$server} ? $Net::Whois::Raw::Data::query_prefix{$server} . '<: $DOMAIN :>' . $CRLF : undef ) // '<: $DOMAIN :>' . $CRLF;
 
         # exceed
-        push $cfg->{server}->{$server}->{exceed_re}->@*, $Pcore::API::Whois::DB->{exceed}->{$server} if $Pcore::API::Whois::DB->{exceed}->{$server};
+        push $cfg->{server}->{$server}->{exceed_re}->@*, $db->{exceed}->{$server} if $db->{exceed}->{$server};
 
         push $cfg->{server}->{$server}->{exceed_re}->@*, $Net::Whois::Raw::Data::exceed{$server} if $Net::Whois::Raw::Data::exceed{$server};
 
         # not found
-        push $cfg->{server}->{$server}->{notfound_re}->@*, $Pcore::API::Whois::DB->{notfound}->{$server} if $Pcore::API::Whois::DB->{notfound}->{$server};
+        push $cfg->{server}->{$server}->{notfound_re}->@*, $db->{notfound}->{$server} if $db->{notfound}->{$server};
 
         push $cfg->{server}->{$server}->{notfound_re}->@*, $Net::Whois::Raw::Data::notfound{$server} if $Net::Whois::Raw::Data::notfound{$server};
     }
@@ -293,8 +293,6 @@ sub _request ( $self, $server, $query, $cb ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 25, 35               | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
-## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    3 | 81                   | Subroutines::ProhibitExcessComplexity - Subroutine "search" with high complexity score (31)                    |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    1 | 39                   | ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     |
